@@ -1,8 +1,7 @@
-
-
 -- Legacy functions without chip functions --
 -- This is the full list including the legacy_minimal.sql (minimal)
 -- so no need to install both legacy and the minimal
+
 -- Bare minimum Legacy functions --
 -- This file that contains what we have determined are
 -- the most common functions used by older apps
@@ -28,6 +27,36 @@
 
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 
 
@@ -105,6 +134,7 @@ CREATE OR REPLACE FUNCTION ST_AsText(bytea)
 	AS
 	$$ SELECT ST_AsText($1::geometry);$$
 	LANGUAGE 'sql' IMMUTABLE STRICT;
+
 --- start functions that in theory should never have been used or internal like stuff deprecated
 
 -- these were superseded by PostGIS_AddBBOX , PostGIS_DropBBOX, PostGIS_HasBBOX in 1.5 --
@@ -343,6 +373,7 @@ BEGIN
 	-- set the correct schema for each geometry_colums record
 	-- looking at table, column, type and srid.
 	
+
 	return 'This function is obsolete now that geometry_columns is a view';
 
 END;
@@ -375,7 +406,6 @@ BEGIN
 
 
 
-
 	RETURN 'This function is obsolete now that geometry_columns is a view';
 END
 
@@ -388,6 +418,7 @@ LANGUAGE 'plpgsql' VOLATILE;
 -- these remarked out functions cause problems and no one uses them directly
 -- They should not be installed
 
+
 -- Deprecation in 1.5.0
 CREATE OR REPLACE FUNCTION st_geometry_lt(geometry, geometry)
 	RETURNS bool
@@ -1767,13 +1798,13 @@ CREATE OR REPLACE FUNCTION StartPoint(geometry)
 -- Deprecation in 1.2.3
 CREATE OR REPLACE FUNCTION symdifference(geometry,geometry)
 	RETURNS geometry
-	AS '$libdir/postgis-3','symdifference'
+	AS '$libdir/postgis-3','ST_SymDifference'
 	LANGUAGE 'c' IMMUTABLE STRICT;
 
 -- Deprecation in 1.2.3
 CREATE OR REPLACE FUNCTION symmetricdifference(geometry,geometry)
 	RETURNS geometry
-	AS '$libdir/postgis-3','symdifference'
+	AS '$libdir/postgis-3','ST_SymDifference'
 	LANGUAGE 'c' IMMUTABLE STRICT;
 
 -- Deprecation in 1.2.3
@@ -2172,3 +2203,4 @@ CREATE OR REPLACE FUNCTION ST_AsKML(version int4, geom geometry, maxdecimaldigit
 	$$ SELECT ST_AsKML($2::geometry,$3,$4); $$
 	LANGUAGE 'sql' IMMUTABLE STRICT;
 
+
